==> haskell-criterion-1.1.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-criterion/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.1.0
id: criterion-1.1.1.0-1de145c9b5289c699ea5ea76f413cf76
key: crite_0mF9DpQWwObCVEUfmk21uB
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/criterion-1.1.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/criterion-1.1.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/criterion-1.1.1.0
hs-libraries: HScriterion-1.1.1.0-0mF9DpQWwObCVEUfmk21uB
depends:
    Glob-0.7.5-2de4d761061e270a9c358a45d1e533d4
    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
    ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cassava-0.4.5.0-16a8710c3a0da375311b9db5f9f0d63e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hastache-0.6.1-98cda3164df6aeeec7ce348b687c9c91
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    statistics-0.13.2.3-2e9fffd6a9f27438d40641d2910361be
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.1.1.0-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-criterion/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion
version: 1.1.1.0
id: criterion-1.1.1.0-d3f1d7734d0ec550847f9a7a12a47a1f
key: crite_24SS7YhlikZ0kmnOTaym4x
license: BSD3
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/criterion
synopsis: Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.
    .
    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.
    .
    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.
category: Development, Performance, Testing, Benchmarking
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Measurement Criterion.Monad Criterion.Report
    Criterion.Types
hidden-modules: Criterion.Monad.Internal Paths_criterion
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/criterion-1.1.1.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/criterion-1.1.1.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/criterion-1.1.1.0
hs-libraries: HScriterion-1.1.1.0-24SS7YhlikZ0kmnOTaym4x
depends:
    Glob-0.7.5-2de4d761061e270a9c358a45d1e533d4
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    ansi-wl-pprint-0.6.7.3-28ee0530b985e8f17809a30013a735ed
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cassava-0.4.5.0-5561f7a2cf4fbc4e852eacf71d5b8fea
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    hastache-0.6.1-7d906c00c2beceb84304bd43ff83230a
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    statistics-0.13.2.3-fb2d29ac22ccabf2cfd4165df330c05e
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
haddock-interfaces: /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html: /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
